@@ -449,7 +449,7 @@ class particles:
         Method to calculate classical particle radius from given reference particle, also ions
         """
         m0 = particle_ref.mass0*1.782661921e-36  # electron volt - kg conversion
-        r0 = (particle_ref.q0**constants.elementary_charge)**2/(4*np.pi*constants.epsilon_0*m0*constants.c**2)  #1.5347e-18 is default for protons
+        r0 = (particle_ref.q0*constants.elementary_charge)**2/(4*np.pi*constants.epsilon_0*m0*constants.c**2)  #1.5347e-18 is default for protons
         return r0
 
 
